@@ -1,5 +1,5 @@
 /**********************************************************************
- This file is based on Qt Designer, Copyright (C) 2000 Trolltech AS. All rights reserved.
+ This file is based on Qt Designer, Copyright (C) 2000 Trolltech AS.  All rights reserved.
 
  This file may be distributed and/or modified under the terms of the
  GNU General Public License version 2 as published by the Free Software
@@ -22,12 +22,17 @@
 
 #include "metadatabase.h"
 
-#include <kparts/dockmainwindow.h>
-#include <kdockwidget.h>
+#include <kxmlguiwindow.h>
+#include <k3dockwidget.h>
 
 #include <qmap.h>
-#include <qguardedptr.h>
-#include <qobjectlist.h>
+#include <qpointer.h>
+#include <qobject.h>
+//Added by qt3to4:
+#include <Q3ValueList>
+#include <Q3PopupMenu>
+#include <QEvent>
+#include <QCloseEvent>
 
 class ActionEditor;
 class AssistProc;
@@ -38,11 +43,10 @@ class GotoLineDialog;
 class HierarchyView;
 class KAction;
 class KActionCollection;
-class KProcess;
+class K3Process;
 class KRecentFilesAction;
 class KToggleAction;
-class KToolBar;
-class KURL;
+class KUrl;
 class PropertyEditor;
 class QCloseEvent;
 class QMenuBar;
@@ -54,18 +58,14 @@ class ReplaceDialog;
 class Workspace;
 
 #if defined(Q_FULL_TEMPLATE_INSTANTIATION)
-#include <qtoolbar.h>
+#include <q3toolbar.h>
 #else
-class QToolBar;
+class Q3ToolBar;
 #endif
 class Preferences;
 
-namespace KParts {
-  class PartManager;
-}
 
-
-class MainWindow : public KParts::DockMainWindow
+class MainWindow : public KDockMainWindow
 {
     Q_OBJECT
 
@@ -93,8 +93,8 @@ public:
     void popupFormWindowMenu( const QPoint &gp, FormWindow *fw );
     void popupWidgetMenu( const QPoint &gp, FormWindow *fw, QWidget *w );
 
-    QPopupMenu *setupNormalHierarchyMenu( QWidget *parent );
-    QPopupMenu *setupTabWidgetHierarchyMenu( QWidget *parent, const char *addSlot, const char *removeSlot );
+    Q3PopupMenu *setupNormalHierarchyMenu( QWidget *parent );
+    Q3PopupMenu *setupTabWidgetHierarchyMenu( QWidget *parent, const char *addSlot, const char *removeSlot );
 
     FormWindow *openFormWindow( const QString &fn, bool validFileName = TRUE, FormFile *ff = 0 );
     
@@ -129,8 +129,7 @@ public slots:
     void showProperties( QObject *w );
     void updateProperties( QObject *w );
     void showDialogHelp();
-    void slotActivePartChanged(KParts::Part * );
-    
+
 signals:
     void addedFormFile(FormFile *);
     void removedFormFile(FormFile *);
@@ -151,7 +150,7 @@ public slots:
     void fileClose();
     void fileOpen();
     void fileOpen(const QString &filename);
-    void fileOpenRecent(const KURL& name);
+    void fileOpenRecent(const KUrl& name);
     bool fileSave();
     bool fileSaveForm(); // not visible in menu, called from fileSave
     bool fileSaveAs();
@@ -179,16 +178,14 @@ public slots:
     void editBreakLayout();
     void editAccels();
     void editConnections();
-    void editFindGlobal();
     
     void editFormSettings();
     void editPreferences();
     void editShortcuts();
     void editPlugins();
     void editExternalTool(int id);
-    void editToolExited(KProcess*);
-    void editToolOutput(KProcess*, char*, int);
-    void configureEditor();
+    void editToolExited(K3Process*);
+    void editToolOutput(K3Process*, char*, int);
 
     void runForm();
     
@@ -206,8 +203,7 @@ private slots:
     void setupWindowActions();
     void createNewTemplate();
     
-    void closeRunningForm(KProcess* process);
-    void slotCreateBackups();
+    void closeRunningForm(K3Process* process);
     
 private:
     void setupMDI();
@@ -232,11 +228,11 @@ private:
     void writeConfig();
     void readConfig();
     
-    void setupRMBProperties( QValueList<int> &ids, QMap<QString, int> &props, QWidget *w );
+    void setupRMBProperties( Q3ValueList<int> &ids, QMap<QString, int> &props, QWidget *w );
     void handleRMBProperties( int id, QMap<QString, int> &props, QWidget *w );
-    void setupRMBSpecialCommands( QValueList<int> &ids, QMap<QString, int> &commands, QWidget *w );
+    void setupRMBSpecialCommands( Q3ValueList<int> &ids, QMap<QString, int> &commands, QWidget *w );
     void handleRMBSpecialCommands( int id, QMap<QString, int> &commands, QWidget *w );
-    void setupRMBSpecialCommands( QValueList<int> &ids, QMap<QString, int> &commands, FormWindow *w );
+    void setupRMBSpecialCommands( Q3ValueList<int> &ids, QMap<QString, int> &commands, FormWindow *w );
     void handleRMBSpecialCommands( int id, QMap<QString, int> &commands, FormWindow *w );
     bool openEditor( QWidget *w, FormWindow *fw );
     void checkTempFiles();
@@ -246,6 +242,8 @@ private:
 
     QString whatsThisFrom( const QString &key );
 
+private slots:
+
 private:
     PropertyEditor *propertyEditor;
     HierarchyView *hierarchyView;
@@ -267,19 +265,18 @@ private:
       *actionEditHLayout, *actionEditVLayout, *actionEditGridLayout,
       *actionEditSplitHorizontal, *actionEditSplitVertical,
       *actionEditSelectAll, *actionEditBreakLayout, *actionEditConnections,
-      *actionEditLower, *actionEditRaise, *actionEditFindGlobal;
+      *actionEditLower, *actionEditRaise;
     
     KToggleAction* actionPointerTool, *actionConnectTool, *actionOrderTool;
     KAction* actionCurrentTool;
     KAction *actionEditFormSettings, *actionEditAccels;
     KRecentFilesAction* actionRecent;
     
-    QPopupMenu *rmbWidgets;
-    QPopupMenu *rmbFormWindow;
-    QPopupMenu *windowMenu, *fileMenu;
+    Q3PopupMenu *rmbWidgets;
+    Q3PopupMenu *rmbFormWindow;
+    Q3PopupMenu *windowMenu, *fileMenu;
 
-    QToolBar *layoutToolBar;
-    KToolBar *fileTb;
+    Q3ToolBar *layoutToolBar;
 
     Preferences *prefDia;
     QMap<QString,QString> propertyDocumentation;
@@ -289,7 +286,6 @@ private:
 
     bool databaseAutoEdit;
     QTimer *updateSlotsTimer;
-    QTimer *backupTimer;
     bool inDebugMode;
     QObjectList debuggingForms;
     QString lastOpenFilter;
@@ -302,11 +298,6 @@ private:
     // Paths of external Kommander tools for Editor
     QStringList m_editorTools;
     QString m_toolOutput;
-    KParts::PartManager *m_partManager;
-
-    QString m_fileName;
-    QString m_backupName;
-    bool m_modified;
 
 public:
     QString lastSaveFilter;
